@@ -1,6 +1,6 @@
 package Enterasys::NetSight;
 {
-  $Enterasys::NetSight::VERSION = '1.0';
+  $Enterasys::NetSight::VERSION = '1.1';
 }
 use strict;
 
@@ -61,7 +61,7 @@ sub getAllDevices
 	while(my($key,$value)=each($call->result->{data} || return undef))
 		{ $devices{$value->{ip}}=$value }
 
-	return %devices;
+	return \%devices;
 }
 sub getDevice
 {
@@ -156,7 +156,7 @@ sub getSnmp
 			{ return undef }
 	}
 
-	return %snmp;
+	return \%snmp;
 }
 sub getAuth
 {
@@ -180,7 +180,7 @@ sub getAuth
 	$creds{user}=$device->{cliUsername};
 	$creds{pass}=$device->{cliLogin};
 	
-	return %creds;
+	return \%creds;
 }
 sub exportDevices
 {
@@ -207,7 +207,7 @@ sub exportDevices
 		$table{$temp{dev}}=\%temp;
 	}
 
-	return $call->result eq ""?undef:%table;
+	return $call->result eq ""?undef:\%table;
 }
 sub ipV6Enabled
 {
@@ -354,7 +354,7 @@ Enterasys::NetSight - Provides an abstraction layer between SOAP::Lite and the N
 
 =head1 VERSION
 
-version 1.0
+version 1.1
 
 =head1 SYNOPSIS
 
@@ -377,11 +377,11 @@ For example the following would print a NetSight Generated Format string contain
 
 However using the getSnmp wrapper method will parse the NGF string into a hash table,
 
-	print Dumper { $netsight->getSnmp({host=>$ip}) };
+	print Dumper $netsight->getSnmp({host=>$ip});
 
 Used with the perl SNMP module you can use the return of that method to create a new SNMP session object,
 
-	my $session = new SNMP::Session($netsight->getSnmp({host=>$ip}));
+	my $session=SNMP::Session->new(%{$netsight->getSnmp({host=>$ip})});
 
 Which you could then use to query a mib,
 
@@ -431,9 +431,9 @@ Building a profile up
 
 Getting info about a profile
 
-	print Dumper { $netsight->getAuth({host=>127.0.0.1, refresh=>1}) };
-	print Dumper { $netsight->getSnmp({host=>'127.0.0.1', level=> ro}) };
-	print Dumper { $netsight->getDevice({host=>$ip}) };
+	print Dumper $netsight->getAuth({host=>127.0.0.1, refresh=>1});
+	print Dumper $netsight->getSnmp({host=>'127.0.0.1', level=> ro});
+	print Dumper $netsight->getDevice({host=>$ip});
 
 =head1 METHODS
 
